@@ -22,6 +22,7 @@ pub mod recvmsg;
 pub mod send;
 pub mod sendmsg;
 pub mod shared_fd;
+pub mod shutdown;
 pub mod socket;
 pub mod stream;
 pub mod timeout;
@@ -36,6 +37,7 @@ pub use recvmsg::RecvMsg;
 pub use send::Send;
 pub use sendmsg::SendMsg;
 pub use shared_fd::SharedFd;
+pub use shutdown::Shutdown;
 pub use socket::Socket;
 pub use stream::Stream;
 pub use timeout::Timeout;
